/*
 * Compile:

gcc -fPIC -c getpid.c -o getpid.o
gcc -shared -o getpid.so getpid.o

 * Use:
 
FORCE_PID=1234 LD_PRELOAD=./getpid.so bash

#
# Copyright (C) 2001-2008 Kees Cook
# kees@outflux.net, http://outflux.net/
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# http://www.gnu.org/copyleft/gpl.html

*/

#include <sys/types.h>
#include <unistd.h>
#include <stdlib.h>

pid_t getpid(void)
{
    return atoi(getenv("FORCE_PID"));
}
